@@ -1,7 +1,7 @@
 use super::{cmd, cmd_arg, Action, OpTrait};
-use crate::{items::TargetData, state::State, term::Term};
+use crate::items::TargetData;
 use derive_more::Display;
-use std::{ffi::OsStr, path::PathBuf, process::Command, rc::Rc};
+use std::{ffi::OsStr, process::Command};
 
 #[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
 #[display(fmt = "Discard")]
@@ -10,22 +10,11 @@ impl OpTrait for Discard {
     fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
         let action = match target.cloned() {
             Some(TargetData::Branch(r)) => cmd_arg(discard_branch, r.into()),
-            Some(TargetData::File(f)) => Rc::new(move |state: &mut State, _term: &mut Term| {
-                let path = PathBuf::from_iter([
-                    state.repo.workdir().expect("No workdir").to_path_buf(),
-                    f.clone(),
-                ]);
-                std::fs::remove_file(path)?;
-                state.screen_mut().update()
-            }),
-            Some(TargetData::Delta(d)) => {
-                if d.old_file == d.new_file {
-                    cmd_arg(checkout_file_cmd, d.old_file.into())
-                } else {
-                    // TODO Discard file move
-                    return None;
-                }
-            }
+            Some(TargetData::File(f)) => cmd_arg(clean_file_cmd, f.into()),
+            Some(TargetData::Delta(d)) => match d.status {
+                git2::Delta::Added => cmd_arg(remove_file_cmd, d.new_file.into()),
+                _ => cmd_arg(checkout_file_cmd, d.old_file.into()),
+            },
             Some(TargetData::Hunk(h)) => {
                 cmd(h.format_patch().into_bytes(), discard_unstaged_patch_cmd)
             }
@@ -46,6 +35,20 @@ fn discard_unstaged_patch_cmd() -> Command {
     cmd
 }
 
+fn clean_file_cmd(file: &OsStr) -> Command {
+    let mut cmd = Command::new("git");
+    cmd.args(["clean", "--force"]);
+    cmd.arg(file);
+    cmd
+}
+
+fn remove_file_cmd(file: &OsStr) -> Command {
+    let mut cmd = Command::new("git");
+    cmd.args(["rm", "--force"]);
+    cmd.arg(file);
+    cmd
+}
+
 fn checkout_file_cmd(file: &OsStr) -> Command {
     let mut cmd = Command::new("git");
     cmd.args(["checkout", "HEAD", "--"]);
