@@ -1,6 +1,7 @@
 use super::{Action, OpTrait};
 use crate::{items::TargetData, prompt::PromptData, state::State, term::Term, Res};
 use derive_more::Display;
+use git2::{Repository, Status, StatusOptions};
 use std::{process::Command, rc::Rc};
 use tui_prompts::State as _;
 
@@ -36,12 +37,14 @@ impl OpTrait for StashWorktree {
                 let input = state.prompt.state.value().to_string();
                 state.prompt.reset(term)?;
 
-                // 1. Stash index (stash@0: index, ...)
-                let mut cmd = Command::new("git");
-                cmd.args(["stash", "push", "--staged"]);
-                state.run_cmd(term, &[], cmd)?;
+                let need_to_stash_index = is_something_staged(&state.repo)?;
+
+                if need_to_stash_index {
+                    let mut cmd = Command::new("git");
+                    cmd.args(["stash", "push", "--staged"]);
+                    state.run_cmd(term, &[], cmd)?;
+                }
 
-                // 2. Stash everything else (stash@0: worktree, stash@1: index, ...)
                 let mut cmd = Command::new("git");
                 cmd.args(["stash", "push", "--include-untracked"]);
                 if !input.is_empty() {
@@ -49,16 +52,20 @@ impl OpTrait for StashWorktree {
                 }
                 state.run_cmd(term, &[], cmd)?;
 
-                // 3. Pop stash with index (at stash@1)
-                let mut cmd = Command::new("git");
-                cmd.args(["stash", "pop", "1"]);
-                state.run_cmd(term, &[], cmd)?;
+                if need_to_stash_index {
+                    let mut cmd = Command::new("git");
+                    cmd.args(["stash", "pop", "1"]);
+                    state.run_cmd(term, &[], cmd)?;
+                }
             }
             Ok(())
         };
 
         Some(Rc::new(
             move |state: &mut State, _term: &mut Term| -> Res<()> {
+                if is_working_tree_empty(&state.repo)? {
+                    return Err("Cannot stash: working tree is empty".into());
+                }
                 state.prompt.set(PromptData {
                     prompt_text: "Name of the stash:".into(),
                     update_fn: Rc::new(update_fn),
@@ -69,6 +76,44 @@ impl OpTrait for StashWorktree {
     }
 }
 
+fn is_working_tree_empty(repo: &Repository) -> Res<bool> {
+    let statuses = repo.statuses(Some(
+        StatusOptions::new()
+            .include_untracked(true)
+            .include_ignored(false),
+    ))?;
+
+    let is_working_tree_not_empty = statuses.iter().any(|e| {
+        e.status().intersects(
+            Status::WT_NEW
+                | Status::WT_MODIFIED
+                | Status::WT_DELETED
+                | Status::WT_RENAMED
+                | Status::WT_TYPECHANGE,
+        )
+    });
+
+    Ok(!is_working_tree_not_empty)
+}
+
+fn is_something_staged(repo: &Repository) -> Res<bool> {
+    let statuses = repo.statuses(Some(
+        StatusOptions::new()
+            .include_untracked(true)
+            .include_ignored(false),
+    ))?;
+
+    Ok(statuses.iter().any(|e| {
+        e.status().intersects(
+            Status::INDEX_NEW
+                | Status::INDEX_MODIFIED
+                | Status::INDEX_DELETED
+                | Status::INDEX_RENAMED
+                | Status::INDEX_TYPECHANGE,
+        )
+    }))
+}
+
 #[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
 #[display(fmt = "Stash keeping index")]
 pub(crate) struct StashKeepIndex;
@@ -137,11 +182,11 @@ impl OpTrait for StashDrop {
 }
 
 fn stash_target_action(command: &'static str) -> Action {
-    Rc::new(|state: &mut State, _term: &mut Term| -> Res<()> {
+    Rc::new(move |state: &mut State, _term: &mut Term| -> Res<()> {
         let prompt_text = if let Some(id) = default_target_stash(state) {
-            format!("Stash index (default {}):", id).into()
+            format!("Stash {} (default {}):", command, id).into()
         } else {
-            "Stash index (default 0):".into()
+            format!("Stash {} (default 0):", command).into()
         };
 
         state.prompt.set(PromptData {
