@@ -18,8 +18,7 @@ use ratatui::layout::Rect;
 use tui_prompts::State as _;
 use tui_prompts::Status;
 
-use crate::bindings;
-use crate::bindings::Binding;
+use crate::bindings::Bindings;
 use crate::cli;
 use crate::config::Config;
 use crate::menu::Menu;
@@ -39,7 +38,7 @@ use super::Res;
 pub(crate) struct State {
     pub repo: Rc<Repository>,
     pub config: Rc<Config>,
-    pub bindings: Vec<Binding>,
+    pub bindings: Bindings,
     pending_keys: Vec<(KeyModifiers, KeyCode)>,
     pub quit: bool,
     pub screens: Vec<Screen>,
@@ -60,8 +59,6 @@ impl State {
     ) -> Res<Self> {
         let repo = Rc::new(repo);
         let config = Rc::new(config);
-        let bindings = bindings::bindings();
-
         let screens = match args.command {
             Some(cli::Commands::Show { ref reference }) => {
                 vec![screen::show::create(
@@ -78,6 +75,8 @@ impl State {
             )?],
         };
 
+        let bindings = Bindings::from(&config.bindings);
+
         Ok(Self {
             repo,
             config,
@@ -154,21 +153,22 @@ impl State {
     }
 
     fn handle_key_input(&mut self, term: &mut Term, key: event::KeyEvent) -> Res<()> {
-        let pending = match &self.pending_menu {
-            None => None,
-            Some(menu) if menu.menu == Menu::Help => None,
-            Some(menu) => Some(menu.menu),
+        let menu = match &self.pending_menu {
+            None => Menu::Root,
+            Some(menu) if menu.menu == Menu::Help => Menu::Root,
+            Some(menu) => menu.menu,
         };
 
         self.pending_keys.push((key.modifiers, key.code));
-        let matching_bindings =
-            bindings::match_bindings(&self.bindings, &pending, &self.pending_keys)
-                .collect::<Vec<_>>();
+        let matching_bindings = self
+            .bindings
+            .match_bindings(&menu, &self.pending_keys)
+            .collect::<Vec<_>>();
 
         match matching_bindings[..] {
             [binding] => {
                 if binding.keys == self.pending_keys {
-                    self.handle_op(binding.op, term)?;
+                    self.handle_op(binding.op.clone(), term)?;
                     self.pending_keys.clear();
                 }
             }
@@ -181,7 +181,7 @@ impl State {
 
     pub(crate) fn handle_op(&mut self, op: Op, term: &mut Term) -> Res<()> {
         let target = self.screen().get_selected_item().target_data.as_ref();
-        if let Some(mut action) = op.implementation().get_action(target) {
+        if let Some(mut action) = op.clone().implementation().get_action(target) {
             let result = Rc::get_mut(&mut action).unwrap()(self, term);
 
             self.close_menu(op);
@@ -205,7 +205,7 @@ impl State {
 
     fn close_menu(&mut self, op: Op) {
         match op {
-            Op::Menu(_) => (),
+            Op::OpenMenu(_) => (),
             Op::ToggleArg(_) => (),
             _ => self.pending_menu = None,
         }
